'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var services = new Map();

/**
 * Discovers a service
 */
function discover(name) {
	if (!services.has(name)) {
		throw new Error("Error discovering service. No " + name + " services found.");
	}

	return services.get(name);
}

/**
 * Mocks a service and returns a function
 * to restore the original service
 */
function mock(name, mockService) {
	var original = services.get(name);
	services.set(name, mockService);

	return function () {
		return services.set(name, original);
	};
}

/**
 * Registers a service
 */
function register(name, service) {
	if (services.has(name)) {
		throw new Error("Error registering service. " + name + " is already registered.");
	}

	services.set(name, service);

	return service;
}

exports.discover = discover;
exports.mock = mock;
exports.register = register;